aboutsummaryrefslogtreecommitdiffstats
path: root/resources/lib/moment/lang/ro.js
diff options
context:
space:
mode:
Diffstat (limited to 'resources/lib/moment/lang/ro.js')
-rw-r--r--resources/lib/moment/lang/ro.js18
1 files changed, 9 insertions, 9 deletions
diff --git a/resources/lib/moment/lang/ro.js b/resources/lib/moment/lang/ro.js
index fc275099005c..21a3293191a1 100644
--- a/resources/lib/moment/lang/ro.js
+++ b/resources/lib/moment/lang/ro.js
@@ -1,5 +1,5 @@
// moment.js language configuration
// language : romanian (ro)
// author : Vlad Gurdiga : https://github.com/gurdiga
// author : Valentin Agachi : https://github.com/avaly
@@ -14,12 +14,12 @@
}(function (moment) {
function relativeTimeWithPlural(number, withoutSuffix, key) {
var format = {
- 'mm': 'minute',
- 'hh': 'ore',
- 'dd': 'zile',
- 'MM': 'luni',
- 'yy': 'ani'
- },
+ 'mm': 'minute',
+ 'hh': 'ore',
+ 'dd': 'zile',
+ 'MM': 'luni',
+ 'yy': 'ani'
+ },
separator = ' ';
if (number % 100 >= 20 || (number >= 100 && number % 100 === 0)) {
separator = ' de ';
@@ -28,7 +28,7 @@
return number + separator + format[key];
}
- return moment.lang('ro', {
+ return moment.defineLocale('ro', {
months : "ianuarie_februarie_martie_aprilie_mai_iunie_iulie_august_septembrie_octombrie_noiembrie_decembrie".split("_"),
monthsShort : "ian._febr._mart._apr._mai_iun._iul._aug._sept._oct._nov._dec.".split("_"),
weekdays : "duminică_luni_marți_miercuri_joi_vineri_sâmbătă".split("_"),
@@ -1,5 +1,5 @@
-// moment.js language configuration
-// language : romanian (ro)
+// moment.js locale configuration
+// locale : romanian (ro)
// author : Vlad Gurdiga : https://github.com/gurdiga
// author : Valentin Agachi : https://github.com/avaly